##  Mapping Responsibilities to Subscriptions
You can map responsibilities from a mapped community, domain, or asset of Collibra to responsible subscription roles in SAP LeanIX.
In the Role Mapping field, choose any roles available in Collibra and map them to relevant subscription roles for the data object fact sheet type. Note that the subscription role has to be of the type Responsible. To learn more about subscriptions, see [Subscription Role](https://help.sap.com/docs/leanix/ea/subscription-roles?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how to create, edit, and delete subscription roles and manage settings like enabling the 'Accountable' type, limiting multiple subscriptions, and enforcing mandatory role selection.").
You can also automatically create users who exist in Collibra but not in SAP LeanIX by selecting the Create Users check box.
![Mapping Responsibilities to Subscriptions](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio27510cea7a441014ae14fec2ccd7f10e_LowRes.png)
Mapping Responsibilities to Subscriptions
The integration will only consider implicit responsibilities and ignore inherited ones. It will also resolve user groups and translate them to the corresponding individuals.
The following image illustrates how the CISO role is mapped between Collibra and SAP LeanIX.
![Responsibilities Mapped to Subscription Role](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio27541ddb7a441014915f96e0b3de8ce6_LowRes.png)
Responsibilities Mapped to Subscription Role
